@@ -41,8 +41,6 @@ def train(
         raise Exception("Path to directory for saving model was not provided.")
 
     device = torch.device("cuda:0" if torch.cuda.is_available() else "cpu")
-    if verbose:
-	  print("Device:", device)
 
     base_model = model_obj.base_model
     model_size = model_obj.model_size
@@ -60,14 +58,12 @@ def train(
         for root, dirs, files in os.walk(logs_folder):
             for file in files:
                 os.remove(os.path.join(root, file))
-	  if verbose:
-       	print("Logs deleted")
+
 
     if load_existing_model:
         state_dict = torch.load(model_save_name)
         model.load_state_dict(state_dict)
-        if verbose:
-            print("Existing model loaded")
+
 
     model = model.to(device)
 
@@ -80,9 +76,6 @@ def train(
     seq_count = 0
     start = time.time()
 
-    if verbose:
-	  print_model(model)
-
 
     for epoch in range(epochs):
 
